"""
This file is auto generated. Do not edit this file manually.
Source code: [monorepo]/contracts/generator.py
Last generated: 2024-01-10 16:15:36.265198
"""

import typing
from dataclasses import dataclass

CloudApiAuthInfoAuthorId = str

CloudApiAuthInfoProjectId = str


@dataclass
class CloudApiAuthInfo:
    authorId: CloudApiAuthInfoAuthorId
    projectId: CloudApiAuthInfoProjectId


CommonUserId = str

CommonUserEmail = str

CommonUserRolesItemValues = ["workflow_viewer"]

CommonUserRolesItem = typing.Literal["workflow_viewer"]

CommonUserRoles = typing.List[CommonUserRolesItem]

CommonUserProjectId = str

CommonUserCreatedAt = str


@dataclass
class CommonUser:
    id: CommonUserId
    email: CommonUserEmail
    roles: CommonUserRoles
    projectId: CommonUserProjectId
    createdAt: CommonUserCreatedAt


CloudApiCliUserGetResponse = CommonUser

CloudApiCliBuildCreateResponseUrl = str

CloudApiCliBuildCreateResponseBuildId = str


@dataclass
class CloudApiCliBuildCreateResponse:
    url: CloudApiCliBuildCreateResponseUrl
    buildId: CloudApiCliBuildCreateResponseBuildId


CloudApiConsoleUserUpdateRequestRoles = CommonUserRoles


@dataclass
class CloudApiConsoleUserUpdateRequest:
    roles: CloudApiConsoleUserUpdateRequestRoles


CloudApiConsoleUserUpdateResponse = CommonUser

CloudApiConsoleUserListQueryOffset = int

CloudApiConsoleUserListQueryLimit = int


@dataclass
class CloudApiConsoleUserListQuery:
    offset: CloudApiConsoleUserListQueryOffset
    limit: CloudApiConsoleUserListQueryLimit


CloudApiConsoleUserListResponseItem = CommonUser

CloudApiConsoleUserListResponse = typing.List[CloudApiConsoleUserListResponseItem]

CloudApiConsoleUserCreateRequestEmail = CommonUserEmail

CloudApiConsoleUserCreateRequestRoles = CommonUserRoles


@dataclass
class CloudApiConsoleUserCreateRequest:
    email: CloudApiConsoleUserCreateRequestEmail
    roles: CloudApiConsoleUserCreateRequestRoles


CloudApiConsoleUserCreateResponse = CommonUser

CommonProjectId = str

CommonProjectName = str

CommonProjectSubdomain = str

CommonProjectOrganizationId = str

CommonProjectCustomDomain0 = type(None)

CommonProjectCustomDomain1 = str

CommonProjectCustomDomain = typing.Union[
    CommonProjectCustomDomain0, CommonProjectCustomDomain1
]


@dataclass
class CommonProject:
    id: CommonProjectId
    name: CommonProjectName
    subdomain: CommonProjectSubdomain
    organizationId: CommonProjectOrganizationId
    customDomain: CommonProjectCustomDomain


CloudApiConsoleProjectDuplicateResponse = CommonProject
