import{d as h,eA as w,eB as k,r as x,G as y,b as n,c as l,w as t,ev as b,eC as I,u as d,bf as C,ez as f,f as s,I as B,aq as N,eD as D,bq as S,bh as V,v as A,eE as E,eF as L,e as g,a as p,ex as T}from"./outputWidgets.470cd725.js";import{h as $,s as q}from"./icons.732210f6.js";import{_ as z}from"./logo.084e5d7c.js";import{B as F}from"./BaseLayout.2265c0ec.js";import{N as H}from"./NavbarControls.9a7c4440.js";import{c as M}from"./index.2b09b2c1.js";import"./asyncComputed.72d91ef9.js";import"./index.36298fea.js";import"./pubsub.bb7b27fb.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.702cb95e.js";import"./SaveButton.vue_vue_type_script_setup_true_lang.9b577b25.js";import"./ant-design.e0dca437.js";import"./index.ea4d1d9c.js";import"./Title.edbac04b.js";import"./Text.fbb768c7.js";import"./index.6ca029a4.js";import"./Link.f333b71a.js";import"./index.e48b3db7.js";import"./workspaces.12470e3b.js";import"./record.19f593f6.js";import"./url.28fafd73.js";import"./popupNotifcation.9c636269.js";import"./CircularLoading.e4e65060.js";import"./index.ee790ec2.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="a6e9d957-4c60-4e51-bf2e-560d400e8cb0",e._sentryDebugIdIdentifier="sentry-dbid-a6e9d957-4c60-4e51-bf2e-560d400e8cb0")}catch{}})();const R=h({__name:"Sidebar",setup(e){var m;const o=w(),c=k(),r=x((m=c.name)!=null?m:"forms"),u=y(()=>[{name:"Home",icon:$,path:"home"},{name:"Settings",icon:q,path:"settings"}]),i=_=>{o.push(_.path),r.value=_.path};return(_,Q)=>(n(),l(d(V),{"inline-collapsed":""},{default:t(()=>[(n(!0),b(S,null,I(u.value,a=>(n(),l(d(C),{key:a.name,role:"button",class:f({active:r.value===a.path}),tabindex:"0",onClick:U=>i(a)},{icon:t(()=>[s(B,{class:f({active:r.value===a.path}),path:a.icon,width:"20",height:"20"},null,8,["class","path"])]),title:t(()=>[N(D(a.name),1)]),_:2},1032,["class","onClick"]))),128))]),_:1}))}});const W={},v=e=>(E("data-v-81cd596e"),e=e(),L(),e),G={class:"logo"},P=v(()=>g("img",{src:z,alt:"Abstra cloud logo"},null,-1)),j=v(()=>g("span",null," Abstra ",-1)),J=[P,j];function K(e,o){return n(),b("div",G,J)}const O=A(W,[["render",K],["__scopeId","data-v-81cd596e"]]),ke=h({__name:"Workspace",setup(e){return(o,c)=>{const r=p("ant-button"),u=p("router-link"),i=p("router-view");return n(),l(F,null,{navbar:t(()=>[s(d(M),{style:{padding:"5px 25px"}},{title:t(()=>[s(O)]),extra:t(()=>[s(H,{"show-github-stars":""},{default:t(()=>[T("",!0)]),_:1})]),_:1})]),sidebar:t(()=>[s(R,{class:"sidebar"})]),content:t(()=>[s(i)]),_:1})}}});export{ke as default};
//# sourceMappingURL=Workspace.5cbe207e.js.map
