import"./outputWidgets.470cd725.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},d=new Error().stack;d&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[d]="719efddd-3d62-4c62-8e04-1e9d4b11c519",e._sentryDebugIdIdentifier="sentry-dbid-719efddd-3d62-4c62-8e04-1e9d4b11c519")}catch{}})();const r=e=>{try{return new URL(e),!0}catch{return!1}};export{r as i};
//# sourceMappingURL=url.28fafd73.js.map
