import{z as t}from"./index.cf4c23b9.js";import{w as n}from"./metadata.c10b307d.js";import"./outputWidgets.470cd725.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="c7b7896d-a170-49d0-9569-d6cadbda2d1a",e._sentryDebugIdIdentifier="sentry-dbid-c7b7896d-a170-49d0-9569-d6cadbda2d1a")}catch{}})();const s=n.stages.flatMap(e=>e.transitions.flatMap(a=>a.typeName)),r=t.object({type:t.enum(["forms","hooks","jobs","scripts","conditions","iterators"]),id:t.string(),title:t.string(),position:t.object({x:t.number(),y:t.number()}),props:t.object({path:t.string().nullable(),filename:t.string().nullable(),variableName:t.string().nullable()})}),o=t.object({id:t.string(),type:t.enum(s),sourceStageId:t.string(),targetStageId:t.string(),props:t.object({conditionValue:t.string().nullable()})}),l=t.object({stages:t.array(r),transitions:t.array(o)});export{l as s};
//# sourceMappingURL=schema.e93b2882.js.map
