import{d as N,r as g,G as S,b as s,ev as m,ds as $,e as k,eD as w,ew as A,v as M,eA as O,eB as V,c as u,w as l,eC as B,u as c,cu as q,aq as f,bq as D,bf as z,ez as I,f as C,I as T,ex as _,bh as E}from"./outputWidgets.470cd725.js";import{J as R}from"./icons.732210f6.js";import{A as h}from"./index.2d4e9800.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[t]="6b30f80c-6a1b-4fc4-91b4-ee8aed9e3d86",o._sentryDebugIdIdentifier="sentry-dbid-6b30f80c-6a1b-4fc4-91b4-ee8aed9e3d86")}catch{}})();const G={class:"text"},L=N({__name:"Tooltip",props:{text:{type:String,required:!0},left:{type:Number},top:{type:Number},fixed:{type:Boolean,default:!1}},setup(o){const t=o,d=g(Date.now()),b=()=>{d.value=Date.now()},i=g(null),y=()=>{var r,e,x;const a=(r=i.value)==null?void 0:r.getBoundingClientRect();if(!a)return{};const{x:n,y:p}=a;return d.value,{position:"fixed",top:`${p+((e=t.top)!=null?e:0)}px`,left:`${n+((x=t.left)!=null?x:0)}px`}},v=S(()=>{var a;return t.fixed?y():{left:`${(a=t.left)!=null?a:-14}px`,...t.top?{top:`${t.top}px`}:{}}});return(a,n)=>(s(),m("div",{ref_key:"tooltipBox",ref:i,class:"tooltip-box",onMouseenter:b},[$(a.$slots,"default",{},void 0,!0),k("div",{class:"tooltip",style:A(v.value)},[k("span",G,w(o.text),1)],4)],544))}});const F=M(L,[["__scopeId","data-v-c3a6ca5e"]]),j=N({__name:"Sidebar",props:{sections:{}},setup(o){var a;const t=o,d=O(),b=V(),i=g((a=b.name)!=null?a:"forms"),y=S(()=>t.sections.map(n=>({...n,items:n.items.filter(p=>!p.unavailable)}))),v=n=>{n.unavailable||(d.push(n.path),i.value=n.path)};return(n,p)=>(s(),u(c(E),null,{default:l(()=>[(s(!0),m(D,null,B(y.value,r=>(s(),u(c(q),{key:r.name},{title:l(()=>[f(w(r.name),1)]),default:l(()=>[(s(!0),m(D,null,B(r.items,e=>(s(),u(c(z),{key:e.name,role:"button",class:I({active:i.value===e.path,disabled:e.unavailable||r.cloud}),tabindex:"0",onClick:x=>v(e)},{icon:l(()=>[C(T,{class:I({disabled:e.unavailable,active:i.value===e.path}),path:e.icon,width:"20",height:"20"},null,8,["class","path"])]),default:l(()=>[k("span",null,w(e.name),1),e.unavailable?(s(),u(c(h),{key:0},{default:l(()=>[f("SOON")]),_:1})):_("",!0),e.beta?(s(),u(c(h),{key:1},{default:l(()=>[f("BETA")]),_:1})):_("",!0),e.cloud?(s(),u(c(h),{key:2},{default:l(()=>[f("CLOUD")]),_:1})):_("",!0),e.warning?(s(),u(F,{key:3,text:e.warning,fixed:!0,top:18,left:18},{default:l(()=>[C(T,{path:c(R),fill:"#D35249",width:"20",height:"20"},null,8,["path"])]),_:2},1032,["text"])):_("",!0)]),_:2},1032,["class","onClick"]))),128))]),_:2},1024))),128))]),_:1}))}});export{j as _};
//# sourceMappingURL=Sidebar.vue_vue_type_script_setup_true_lang.61937729.js.map
