html,body{overscroll-behavior-x:none}.workflow[data-v-e9c7c43a]{display:flex;flex-direction:column;outline:none}.workflow .title[data-v-e9c7c43a]{display:flex;align-items:center;gap:10px}.workflow .title:not(:hover) .edit-icon[data-v-e9c7c43a]{display:none}.workflow .title .edit-icon[data-v-e9c7c43a]{cursor:pointer}
