import{d as k,eB as B,eA as I,G as w,a as h,b as o,c as d,w as a,eK as j,f as n,u as t,ev as l,eC as x,aq as g,eD as z,bq as C,ex as A,bg as D,cC as S}from"./outputWidgets.470cd725.js";import{B as $}from"./BaseLayout.2265c0ec.js";import{a as M}from"./asyncComputed.72d91ef9.js";import{_ as N}from"./component.vue_vue_type_script_setup_true_lang.ac0eb560.js";import"./authorManager.176ccd94.js";import{a as P}from"./build.dabf30ab.js";import"./index.d44cde0e.js";import{P as R}from"./project.f4c30a7f.js";import{O as V}from"./organization.76eeda0f.js";import{B as q,a as E,c as L}from"./index.2b09b2c1.js";import{A as O}from"./Text.fbb768c7.js";import"./gateway.6d700df7.js";import"./Log.77f22fc7.js";import"./ant-design.e0dca437.js";import"./index.ea4d1d9c.js";import"./Title.edbac04b.js";import"./StarFilled.fad29e50.js";import"./Timeline.1b6d13aa.js";import"./WarningFilled.d99917ef.js";import"./Link.f333b71a.js";import"./index.672f7932.js";import"./log.e43ffc68.js";import"./TabPane.954c3f4b.js";import"./hasIn.6bd3aa8a.js";import"./index.df5ed4f2.js";import"./isNumeric.75337b1e.js";import"./icons.732210f6.js";import"./index.0d40618a.js";import"./FormItem.bd89e955.js";import"./index.cf4c23b9.js";import"./record.19f593f6.js";import"./pubsub.bb7b27fb.js";(function(){try{var i=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(i._sentryDebugIds=i._sentryDebugIds||{},i._sentryDebugIds[s]="94d9554e-0a25-4ab6-81b7-56568da7e090",i._sentryDebugIdIdentifier="sentry-dbid-94d9554e-0a25-4ab6-81b7-56568da7e090")}catch{}})();const T={key:0},F={key:2},It=k({__name:"Build",setup(i){const s=B(),m=I(),c=s.params.buildId,{result:e,loading:b}=M(async()=>{const r=await P.get(c),p=await R.get(r.projectId),u=await V.get(p.organizationId);return j({bs:r,project:p,organization:u})}),f=w(()=>!b.value&&e.value?[{label:"My organizations",path:"/organizations"},{label:e.value.organization.name,path:`/organizations/${e.value.organization.id}`},{label:`Build ${c.split("-")[0]}`,path:`/projects/${e.value.project.id}/builds`}]:void 0);function y(){var r;(r=e.value)!=null&&r.project.id&&m.push({name:"builds",params:{projectId:e.value.project.id}})}return(r,p)=>{const u=h("router-link");return o(),d($,null,{navbar:a(()=>[n(t(L),{title:"Inspect Build",style:{padding:"5px 25px"},onBack:y},{breadcrumb:a(()=>[f.value?(o(),d(t(q),{key:0},{default:a(()=>[(o(!0),l(C,null,x(f.value,(_,v)=>(o(),d(t(E),{key:v},{default:a(()=>[n(u,{to:_.path},{default:a(()=>[g(z(_.label),1)]),_:2},1032,["to"])]),_:2},1024))),128))]),_:1})):A("",!0)]),_:1})]),content:a(()=>[t(b)?(o(),l("div",T,[n(t(D))])):t(e)?(o(),d(N,{key:1,"build-spec":t(e).bs},null,8,["build-spec"])):(o(),l("div",F,[n(t(S),{direction:"vertical"},{default:a(()=>[n(t(O),null,{default:a(()=>[g("Could not find build")]),_:1})]),_:1})]))]),_:1})}}});export{It as default};
//# sourceMappingURL=Build.51f274d0.js.map
