import{N as f}from"./NavbarControls.9a7c4440.js";import{d as _,eA as b,eB as y,G as g,a as v,b as c,ev as h,f as e,w as s,u as a,e as k,bq as w,aq as x,c as S,eU as q,v as A}from"./outputWidgets.470cd725.js";import{A as B}from"./Text.fbb768c7.js";import{T as C,A as o}from"./TabPane.954c3f4b.js";import{c as I}from"./index.2b09b2c1.js";import"./asyncComputed.72d91ef9.js";import"./index.36298fea.js";import"./pubsub.bb7b27fb.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.702cb95e.js";import"./SaveButton.vue_vue_type_script_setup_true_lang.9b577b25.js";import"./ant-design.e0dca437.js";import"./index.ea4d1d9c.js";import"./Title.edbac04b.js";import"./index.6ca029a4.js";import"./Link.f333b71a.js";import"./index.e48b3db7.js";import"./workspaces.12470e3b.js";import"./record.19f593f6.js";import"./url.28fafd73.js";import"./popupNotifcation.9c636269.js";import"./CircularLoading.e4e65060.js";import"./icons.732210f6.js";import"./index.ee790ec2.js";import"./hasIn.6bd3aa8a.js";(function(){try{var r=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(r._sentryDebugIds=r._sentryDebugIds||{},r._sentryDebugIds[t]="aef8b800-fcd5-4022-8098-84e1a167d1a6",r._sentryDebugIdIdentifier="sentry-dbid-aef8b800-fcd5-4022-8098-84e1a167d1a6")}catch{}})();const T={class:"content"},D=_({__name:"Settings",setup(r){const t=b(),n=y();function m(){t.push({name:"home"})}const u=g(()=>{switch(n.name){case"settingsStyle":return"style";case"settingsSidebar":return"sidebar";case"settingsRequirements":return"requirements";default:return}});function p(i){switch(i){case"style":t.push({name:"settingsStyle"});break;case"sidebar":t.push({name:"settingsSidebar"});break;case"requirements":t.push({name:"settingsRequirements"});break}}return(i,N)=>{const d=v("router-view");return c(),h(w,null,[e(a(I),{style:{padding:"5px 25px"},onBack:m},{extra:s(()=>[e(f,{"show-v-s-code-button":"","show-save-button":""})]),avatar:s(()=>[e(a(B),null,{default:s(()=>[x("Settings")]),_:1})]),footer:s(()=>[e(a(C),{"active-key":u.value,onChange:p},{default:s(()=>[e(a(o),{key:"style",tab:"Style"}),e(a(o),{key:"sidebar",tab:"Sidebar"}),e(a(o),{key:"requirements",tab:"Requirements"})]),_:1},8,["active-key"])]),_:1}),k("div",T,[e(d,null,{default:s(({Component:l})=>[(c(),S(q(l)))]),_:1})])],64)}}});const ae=A(D,[["__scopeId","data-v-772f4b10"]]);export{ae as default};
//# sourceMappingURL=Settings.42752005.js.map
