import{a as e,A as t,B as i}from"./Text.fbb768c7.js";import{A as o}from"./Link.f333b71a.js";import{a as r,A as d}from"./Title.edbac04b.js";(function(){try{var n=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(n._sentryDebugIds=n._sentryDebugIds||{},n._sentryDebugIds[a]="0071ad60-7df4-4e95-95dc-b62436c83144",n._sentryDebugIdIdentifier="sentry-dbid-0071ad60-7df4-4e95-95dc-b62436c83144")}catch{}})();e.Text=t;e.Title=r;e.Paragraph=d;e.Link=o;e.Base=i;e.install=function(n){return n.component(e.name,e),n.component(e.Text.displayName,t),n.component(e.Title.displayName,r),n.component(e.Paragraph.displayName,d),n.component(e.Link.displayName,o),n};
//# sourceMappingURL=index.6ca029a4.js.map
