import{v as o,a as i,b as a,c,i as d,T as p,j as u,P as f,C as _,M as l,s as g,k as s,l as m,m as y,n as b,p as v}from"./outputWidgets.470cd725.js";import{u as w,s as h,a as r}from"./index.36298fea.js";import"./pubsub.bb7b27fb.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="80681f45-735f-4fa3-aec8-be01d477de42",e._sentryDebugIdIdentifier="sentry-dbid-80681f45-735f-4fa3-aec8-be01d477de42")}catch{}})();const I={};function k(e,t){const n=i("router-view");return a(),c(n,{style:{"min-height":"100vh","box-sizing":"border-box",width:"100%"}})}const x=o(I,[["render",k]]);class P{static init(){setInterval(()=>fetch("/_version"),20*1e3)}}(async()=>{await Promise.all([w(),h()]);const e=d({render:()=>m(x)});p.init(),u(e,r),P.init(),e.use(r),e.use(f),e.mount("#app"),e.component("VSelect",_),e.component("Markdown",l),e.component("Message",g),s(e,y),s(e,b),s(e,v)})();
//# sourceMappingURL=player.7e60eeb7.js.map
