import{C as n}from"./gateway.6d700df7.js";import"./outputWidgets.470cd725.js";(function(){try{var s=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(s._sentryDebugIds=s._sentryDebugIds||{},s._sentryDebugIds[e]="31326a85-e33e-40bb-9cb0-c95a4aece54e",s._sentryDebugIdIdentifier="sentry-dbid-31326a85-e33e-40bb-9cb0-c95a4aece54e")}catch{}})();class c{list({projectId:e,buildId:t,...r}){return n.post(`projects/${e}/builds/${t}/logs`,r)}filters(e){return n.get(`projects/${e}/log-filters`)}}const a=new c;class i{constructor(e,t,r,o,l,u,d){this.executionId=e,this.runtimeType=t,this.runtimeName=r,this.payload=o,this.event=l,this.buildId=u,this.createdAt=d}static fromDTO(e){return new i(e.executionId,e.runtimeType,e.runtimeName,e.payload,e.event,e.buildId,new Date(e.createdAt))}static async list(e){const t=await a.list(e);return{total:t.total,logs:t.logs.map(i.fromDTO)}}static async filters(e){return a.filters(e)}get displayPayload(){return this.event==="start"?"Start":this.event==="end"?"End":this.event==="stdout"?this.payload.log:this.event==="stderr"?this.payload.log:JSON.stringify(this.payload)}get execId(){return this.executionId.slice(0,8)}}export{i as L};
//# sourceMappingURL=log.e43ffc68.js.map
