import{C as n}from"./gateway.6d700df7.js";import"./outputWidgets.470cd725.js";(function(){try{var a=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(a._sentryDebugIds=a._sentryDebugIds||{},a._sentryDebugIds[t]="2bfed74b-39a1-414f-b84e-501ddcf9ccf3",a._sentryDebugIdIdentifier="sentry-dbid-2bfed74b-39a1-414f-b84e-501ddcf9ccf3")}catch{}})();class i{async create(t){return n.post(`organizations/${t.organizationId}/members`,{email:t.email})}async delete(t){return n.delete(`organizations/${t.organizationId}/members/${t.authorId}`)}async list(t){return n.get(`organizations/${t}/members`)}async get(t,e){return n.get(`organizations/${t}/members/${e}`)}async login(){return n.post("authors",{})}async onboarding(){return n.get("authors/onboarding")}}const r=new i;class s{constructor(t){this.dto=t}static async login(){return r.login()}static async onboarding(){return r.onboarding()}static async list(t){return(await r.list(t)).map(o=>new s(o))}static async create(t,e){const o=await r.create({organizationId:t,email:e});return new s(o)}static async get(t,e){const o=await r.get(t,e);return new s(o)}static async delete(t,e){return r.delete({organizationId:t,authorId:e})}get email(){return this.dto.email}get name(){return this.dto.name}get role(){return this.dto.role}get id(){return this.dto.authorId}get authorId(){return this.dto.authorId}}export{s as M};
//# sourceMappingURL=member.494808c2.js.map
