import{_ as c}from"./Sidebar.vue_vue_type_script_setup_true_lang.61937729.js";import{_ as p}from"./Navbar.vue_vue_type_script_setup_true_lang.e9e0ed0d.js";import{G as d,H as l,I as u}from"./icons.732210f6.js";import{d as b,eB as f,G as _,a as g,b as y,c as v,w as t,f as r}from"./outputWidgets.470cd725.js";import{a as w}from"./asyncComputed.72d91ef9.js";import"./authorManager.176ccd94.js";import"./index.d44cde0e.js";import{O as z}from"./organization.76eeda0f.js";import{B as I}from"./BaseLayout.2265c0ec.js";import"./index.2d4e9800.js";import"./logo.084e5d7c.js";import"./Text.fbb768c7.js";import"./index.2b09b2c1.js";import"./index.cf4c23b9.js";import"./record.19f593f6.js";import"./pubsub.bb7b27fb.js";import"./gateway.6d700df7.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="3ad0a479-0b2a-4905-8903-5d2e842e4c2a",e._sentryDebugIdIdentifier="sentry-dbid-3ad0a479-0b2a-4905-8903-5d2e842e4c2a")}catch{}})();const A=b({__name:"Organization",setup(e){const n=f().params.organizationId,{result:a}=w(()=>z.get(n)),i=_(()=>a.value?[{label:"My organizations",path:"/organizations"},{label:a.value.name,path:`/organizations/${a.value.id}`}]:void 0),s=[{name:"Organization",items:[{name:"Projects",icon:d,path:"projects"},{name:"Members",icon:l,path:"members"},{name:"Billing",icon:u,path:"billing"}]}];return(h,B)=>{const m=g("router-view");return y(),v(I,null,{navbar:t(()=>[r(p,{breadcrumb:i.value},null,8,["breadcrumb"])]),sidebar:t(()=>[r(c,{class:"sidebar",sections:s})]),content:t(()=>[r(m)]),_:1})}}});export{A as default};
//# sourceMappingURL=Organization.27dc6a53.js.map
