import{U as a}from"./outputWidgets.470cd725.js";import{c as s,d as i}from"./index.15f0298a.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},c=new Error().stack;c&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[c]="89d3dd6d-fe2e-4ceb-9633-7a8cb1b97597",e._sentryDebugIdIdentifier="sentry-dbid-89d3dd6d-fe2e-4ceb-9633-7a8cb1b97597")}catch{}})();const{DatePicker:n,WeekPicker:r,MonthPicker:t,YearPicker:f,TimePicker:m,QuarterPicker:o,RangePicker:d}=s(i),y=a(n,{WeekPicker:r,MonthPicker:t,YearPicker:f,RangePicker:d,TimePicker:m,QuarterPicker:o,install:e=>(e.component(n.name,n),e.component(d.name,d),e.component(t.name,t),e.component(r.name,r),e.component(o.name,o),e)});export{y as D,t as M,o as Q,d as R,r as W};
//# sourceMappingURL=dayjs.708405e3.js.map
