import{v as t,b as d,ev as s}from"./outputWidgets.470cd725.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="85d39f18-025d-4d03-840d-5878d8910d48",e._sentryDebugIdIdentifier="sentry-dbid-85d39f18-025d-4d03-840d-5878d8910d48")}catch{}})();const o={},r={class:"organization-settings"};function i(e,n){return d(),s("div",r,"Organization settings")}const f=t(o,[["render",i]]);export{f as default};
//# sourceMappingURL=OrganizationSettings.e422f632.js.map
