import{cw as n}from"./outputWidgets.470cd725.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="62bf63b5-e4c2-40b0-a771-c5d68bb8706f",e._sentryDebugIdIdentifier="sentry-dbid-62bf63b5-e4c2-40b0-a771-c5d68bb8706f")}catch{}})();const b=(e,r)=>{n.error({message:e,description:r})};export{b as p};
//# sourceMappingURL=popupNotifcation.9c636269.js.map
