import{d as c,eB as m,u as e,b as d,c as u,ev as y,f as a,w as o,bg as _,aq as p,ex as g,e as b,eD as x}from"./outputWidgets.470cd725.js";import"./authorManager.176ccd94.js";import"./index.d44cde0e.js";import{O as w}from"./organization.76eeda0f.js";import{a as k}from"./asyncComputed.72d91ef9.js";import{a as B}from"./Title.edbac04b.js";import{A as h}from"./index.ee790ec2.js";import{A}from"./index.52ab7ae6.js";import{A as C}from"./Text.fbb768c7.js";import{C as D}from"./Card.5513edb0.js";import"./index.cf4c23b9.js";import"./record.19f593f6.js";import"./pubsub.bb7b27fb.js";import"./gateway.6d700df7.js";import"./index.27cce005.js";import"./TabPane.954c3f4b.js";import"./hasIn.6bd3aa8a.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[r]="434fd79f-c7ef-4d95-8667-053ca8cb106a",t._sentryDebugIdIdentifier="sentry-dbid-434fd79f-c7ef-4d95-8667-053ca8cb106a")}catch{}})();const I={key:1},v={style:{display:"flex","justify-content":"flex-end","font-size":"24px"}},Q=c({__name:"Billing",setup(t){const n=m().params.organizationId,{loading:f,result:l}=k(()=>w.get(n));return(z,N)=>e(f)?(d(),u(e(_),{key:0})):(d(),y("div",I,[a(e(h),{justify:"space-between",align:"center"},{default:o(()=>[a(e(B),{level:3},{default:o(()=>[p("Current plan")]),_:1}),g("",!0)]),_:1}),a(e(A),{style:{"margin-top":"0"}}),a(e(D),{style:{width:"300px"}},{default:o(()=>{var i,s;return[a(e(C),{type:"secondary"},{default:o(()=>[p("Plan")]),_:1}),b("div",v,x((s=(i=e(l))==null?void 0:i.billingMetadata)==null?void 0:s.plan),1)]}),_:1})]))}});export{Q as default};
//# sourceMappingURL=Billing.1a5e6348.js.map
