import{F as I,r as R,g as B,R as P}from"./FormRunner.77181ef4.js";import{d as q,eB as x,eA as F,F as D,H as d,G as y,u as p,b as s,ev as u,f as E,c as S,eE as K,eF as L,e as c,v as N}from"./outputWidgets.470cd725.js";import{u as h}from"./uuid.4dd9050a.js";import{a as A}from"./asyncComputed.72d91ef9.js";import{L as C}from"./CircularLoading.e4e65060.js";import"./url.28fafd73.js";import"./index.36298fea.js";import"./pubsub.bb7b27fb.js";import"./icons.732210f6.js";import"./PlayerNavbar.040d8e3c.js";import"./ActionButton.8596ae90.js";import"./WidgetsFrame.e6f94457.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[t]="ac9f27cf-4a46-4ed7-b515-5a2bd719b15e",o._sentryDebugIdIdentifier="sentry-dbid-ac9f27cf-4a46-4ed7-b515-5a2bd719b15e")}catch{}})();const l=o=>(K("data-v-485e3719"),o=o(),L(),o),T={key:0,class:"loading"},V={key:1,class:"error"},G=l(()=>c("h1",null,"Oops! Something went wrong",-1)),H=l(()=>c("p",null,"An unknown error ocurred. Please try again or contact support.",-1)),O=[G,H],j={key:2,class:"form"},z={key:3,class:"error not-found",style:{height:"100vh"}},J=l(()=>c("h1",null,"Page not found",-1)),M=l(()=>c("p",null,"The page you requested could not be found.",-1)),Q=[J,M],U=q({__name:"Player",setup(o){const t=x(),i=F(),_=D({playerKey:h()});d(t,()=>w());function v(e,a){R("player",i,e,a)}const g=({path:e})=>{i.push({name:"player",query:t.query,params:{path:e.split("/")}})},f=async()=>{_.playerKey=h()};d([()=>t.path,()=>t.query],()=>f());const{loading:b,result:r,error:k,refetch:w}=A(()=>{var e;return B((e=t.path.slice(1))!=null?e:"")}),m=y(()=>n.value?P.create(n.value.id):null),n=y(()=>{var e,a;return(a=(e=r.value)==null?void 0:e.form)!=null?a:null});return d(r,()=>{var e;!r.value||r.value.form&&(document.title=(e=r.value.form.welcomeTitle)!=null?e:r.value.form.title)}),(e,a)=>p(b)?(s(),u("div",T,[E(C)])):p(k)?(s(),u("div",V,O)):n.value&&m.value?(s(),u("div",j,[(s(),S(I,{key:_.playerKey,class:"player",form:n.value,"is-preview":!1,params:p(t).query,broker:m.value,"enable-auto-focus":!0,onNavigate:g,onLogout:f,onRedirect:v},null,8,["form","params","broker"]))])):(s(),u("div",z,Q))}});const ue=N(U,[["__scopeId","data-v-485e3719"]]);export{ue as default};
//# sourceMappingURL=Player.90c07d08.js.map
